@@ -9,7 +9,7 @@ from typing import Optional  # noqa
 import numpy
 from pudb import set_trace as bp  # noqa
 
-from radiocc import Export, L2Data, Scenario
+from radiocc.model import Export, L2Data, Scenario
 
 
 def run(SCENARIO: Scenario, L2DATA: L2Data, OUT: Export) -> None:
